@echo off
if "%OS%" == "Windows_NT" setlocal
rem ---------------------------------------------------------------------------
rem NT Service Install/Uninstall script
rem
rem Options
rem install                Install the service using Tomcat5 as service name.
rem                        Service is installed using default settings.
rem remove                 Remove the service from the System.
rem
rem name        (optional) If the second argument is present it is considered
rem                        to be new service name                                           
rem
rem $Id: service.bat$
rem ---------------------------------------------------------------------------

rem Guess CATALINA_HOME if not defined
set CURRENT_DIR=%cd%
set JAVA_HOME=%CURRENT_DIR%\jre

rem Convert the current working directory
rem to a format that is valid for use in a
rem a file URL
set CUR_PATH=%cd%
set DRIVE=%cd:~0,1%
set SHORT_PATH=%~sp0%
set SHORT_PATH=%SHORT_PATH:\=/%
set PATH_URL=%DRIVE%%%3a%SHORT_PATH%

rem The following four environment variables (*_ABSPATH) are used to point to a
rem directory that contains the appropriate JDBC jar file supplied by the
rem database vendor.  Users may set these variables; if they are set, the script
rem will respect their value.  If they are unset, we look in a directory under
rem <JazzInstallDir>/server by default.  (For example, the default location for
rem the Oracle JDBC driver is under <JazzInstallDir>/server/oracle).

rem Do not use double quotes when you define your environment variable.  If
rem you're setting it from the command line, do:
rem set ORACLE_ABSPATH=c:\path name
rem not:
rem set ORACLE_ABSPATH="c:\path name"

set START_DIR=%~dp0

if "%ORACLE_ABSPATH%"=="" goto :default_oracle
set ORACLE_JDBC=%ORACLE_ABSPATH%
goto :after_oracle
:default_oracle
set ORACLE_JDBC=%START_DIR%\oracle
:after_oracle


if "%SQLSERVER_ABSPATH%"=="" goto :default_sqlserver
set SQLSERVER_JDBC=%SQLSERVER_ABSPATH%
goto :after_sqlserver
:default_sqlserver
set SQLSERVER_JDBC=%START_DIR%\sqlserver
:after_sqlserver


if "%DB2I_ABSPATH%"=="" goto :default_db2i
set DB2I_JDBC=%DB2I_ABSPATH%
goto :after_db2i
:default_db2i
set DB2I_JDBC=%START_DIR%\db2i
:after_db2i


if "%DB2Z_ABSPATH%"=="" goto :default_db2z
set DB2Z_JDBC=%DB2Z_ABSPATH%
goto :after_db2z
:default_db2z
set DB2Z_JDBC=%START_DIR%\db2z
:after_db2z

:modify teamserver.properties file
@echo off
setlocal enabledelayedexpansion

SET CURRENT_DIR=%cd%
SET CURRENT_DIR_REVERT=%CURRENT_DIR:\=/%
SET FILE_DIR=%CURRENT_DIR%\conf\jazz
CD %FILE_DIR%

SET REPLACED_DB_DIR="com.ibm.team.repository.db.jdbc.location=repositoryDB"
SET REPLACED_INDEX_DIR="com.ibm.team.fulltext.indexLocation=workitemindex"

SET REPLACEWITH_DB_DIR=com.ibm.team.repository.db.jdbc.location=%CURRENT_DIR_REVERT%/repositoryDB
SET REPLACEWITH_INDEX_DIR=com.ibm.team.fulltext.indexLocation=%CURRENT_DIR_REVERT%/workitemindex

FOR /F "usebackq delims=" %%i IN ("teamserver.properties") DO (
  SET "line=%%i"  
  IF "!line!"==!REPLACED_DB_DIR! SET line=!REPLACEWITH_DB_DIR!
  IF "!line!"==!REPLACED_INDEX_DIR! SET line=!REPLACEWITH_INDEX_DIR!
  ECHO !line!>>"teamserver.properties.backup"
)
  DEL teamserver.properties
 FOR /F "usebackq delims=" %%i IN ("teamserver.properties.backup") DO (
  SET "line=%%i"  
  ECHO !line!>>"teamserver.properties"
 )
  DEL teamserver.properties.backup

if not "%CATALINA_HOME%" == "" goto gotHome
set CATALINA_HOME=%CURRENT_DIR%\tomcat
if exist "%CATALINA_HOME%\bin\tomcat5.exe" goto okHome
:gotHome
if exist "%CATALINA_HOME%\bin\tomcat5.exe" goto okHome
echo The tomcat.exe was not found...
echo The CATALINA_HOME environment variable is not defined correctly.
echo This environment variable is needed to run this program
goto end
rem Make sure prerequisite environment variables are set
if not "%JAVA_HOME%" == "" goto okHome
echo The JAVA_HOME environment variable is not defined
echo This environment variable is needed to run this program
goto end 
:okHome
if not "%CATALINA_BASE%" == "" goto gotBase
set CATALINA_BASE=%CATALINA_HOME%
:gotBase
 
set EXECUTABLE=%CATALINA_HOME%\bin\tomcat5.exe

rem Set default Service name
set SERVICE_NAME=RQM
set PR_DISPLAYNAME=IBM Rational Quality Manager

if "%1" == "" goto displayUsage
if "%2" == "" goto setServiceName
set PR_DISPLAYNAME=%PR_DISPLAYNAME% %2
:setServiceName
if %1 == install goto doInstall
if %1 == remove goto doRemove
if %1 == uninstall goto doRemove
echo Unknown parameter "%1"
:displayUsage
echo.
echo Usage: rqm.service.bat install/remove [server_version]
echo.
    echo example: rqm.service.bat install 2.0.1
goto end

:doRemove
rem Remove the service
"%EXECUTABLE%" //DS//%SERVICE_NAME%
echo The service '%SERVICE_NAME%' has been removed
goto end

:doInstall
rem Install the service
echo Installing the service '%SERVICE_NAME%' ...
echo Using CATALINA_HOME:    %CATALINA_HOME%
echo Using CATALINA_BASE:    %CATALINA_BASE%
echo Using JAVA_HOME:        %JAVA_HOME%
echo using CONFIGURE_DIR:    file:///%PATH_URL%conf
echo using TEMP:			 %TEMP%

rem Use the environment variables as an example
rem Each command line option is prefixed with PR_

set PR_DESCRIPTION=%PR_DISPLAYNAME%
set PR_INSTALL=%EXECUTABLE%
set PR_LOGPATH=%CATALINA_BASE%\logs
set PR_CLASSPATH=%CATALINA_HOME%\bin\bootstrap.jar

rem Set the server jvm from JRE of RQM
set PR_JVM=%CURRENT_DIR%\jre\bin\j9vm\jvm.dll
if exist "%PR_JVM%" goto foundJvm
rem Set the client jvm from JAVA_HOME
set PR_JVM=%JAVA_HOME%\jre\bin\client\jvm.dll
if exist "%PR_JVM%" goto foundJvm
rem Check for JRockit JVM: Bugzilla 39674
set PR_JVM=%JAVA_HOME%\jre\bin\jrockit\jvm.dll
if exist "%PR_JVM%" goto foundJvm
set PR_JVM=auto

:foundJvm
echo Using JVM:              %PR_JVM%
"%EXECUTABLE%" //IS//%SERVICE_NAME% --DisplayName="%PR_DISPLAYNAME%" --Startup=auto --StartClass org.apache.catalina.startup.Bootstrap --StopClass org.apache.catalina.startup.Bootstrap --StartParams start --StopParams stop
if not errorlevel 1 goto installed
echo Failed installing '%SERVICE_NAME%' service
goto end
:installed
rem Clear the environment variables. They are not needed any more.
set PR_DISPLAYNAME=
set PR_DESCRIPTION=
set PR_INSTALL=
set PR_LOGPATH=
set PR_CLASSPATH=
set PR_JVM=
rem Set extra parameters
set SERVER=%CURRENT_DIR%
echo %SERVER%
CD %CURRENT_DIR%
"%EXECUTABLE%" //US//%SERVICE_NAME% --Jvm="%SERVER%\jre\bin\j9vm\jvm.dll"
"%EXECUTABLE%" //US//%SERVICE_NAME% --JvmOptions "-Dcatalina.base=%CATALINA_BASE%;-Dcatalina.home=%CATALINA_HOME%;-Djava.endorsed.dirs=%CATALINA_HOME%\common\endorsed" --StartMode jvm --StopMode jvm
rem More extra parameters
set PR_LOGPATH=%CATALINA_BASE%\logs
set PR_STDOUTPUT=auto
set PR_STDERROR=auto
"%EXECUTABLE%" //US//%SERVICE_NAME% ++JvmOptions "-Djava.awt.headless=true;-DSQLSERVER_JDBC=%SQLSERVER_JDBC%;-DORACLE_JDBC=%ORACLE_JDBC%;-DDB2I_JDBC=%DB2I_JDBC%;-DDB2Z_JDBC=%DB2Z_JDBC%;-Dorg.eclipse.emf.ecore.plugin.EcorePlugin.doNotLoadResourcesPlugin=true;-DJAZZ_HOME=file:///%PATH_URL%conf;-Dcom.ibm.team.repository.tempDir=%TEMP%" --JvmMs 128 --JvmMx 700
echo The service '%SERVICE_NAME%' has been installed.

:end
cd %CURRENT_DIR%
